import numpy as np
import os
from adari_core.plots.panel import Panel
from adari_core.plots.images import ImagePlot
from adari_core.plots.points import LinePlot
from adari_core.plots.text import TextPlot
from adari_core.data_libs.master_sky_flat import MasterSkyFlatReport
from . import MuseReportMixin


class MuseSkyFlatReport(MuseReportMixin, MasterSkyFlatReport):
    files_needed = {}
    center_size = 500

    def __init__(self):
        super().__init__("muse_sky_flat_report")
        self.panel_kwargs = {"x": 1, "y": 1, "height_ratios": [1, 5]}

    def parse_sof(self):
        """Returns a list of files selected from a set of frames (sof).

        If more than one file fullfills the criteria, the first file
        in the array will be selected.
        """
        for path, cat in self.inputs:
            if cat == "TWILIGHT_CUBE":
                self.files_needed["TWILIGHT_CUBE"] = path
                break
        return [self.files_needed]

    def generate_panels(self, **kwargs):
        panels = {}
        extname = "white_div_global"
        """Create both single and multiple extension panels."""
        for hdul_dict in self.hdus:
            if "TWILIGHT_CUBE" in hdul_dict.keys():
                panel = self.img_grid_panel(
                    [hdul_dict["TWILIGHT_CUBE"]["white_div_global"]],
                    zoom_in=True,
                    img_ext=(2, 1),
                )

                col1 = (
                    str(hdul_dict["TWILIGHT_CUBE"][0].header.get("INSTRUME")),
                    "PRO CATG: "
                    + str(
                        hdul_dict["TWILIGHT_CUBE"][0].header.get(
                            "HIERARCH ESO PRO CATG"
                        )
                    ),
                    "EXTNAME: " + extname,
                    "FILE NAME: "
                    + os.path.basename(hdul_dict["TWILIGHT_CUBE"].filename()),
                    "RAW1 NAME: "
                    + str(
                        hdul_dict["TWILIGHT_CUBE"][0].header.get(
                            "HIERARCH ESO PRO REC1 RAW1 NAME"
                        )
                    ),
                )
                col2 = (
                    "INS.MODE: "
                    + str(
                        hdul_dict["TWILIGHT_CUBE"][0].header.get(
                            "HIERARCH ESO INS MODE", "N/A"
                        )
                    ),
                    "INS.OPTI1.NAME: "
                    + str(
                        hdul_dict["TWILIGHT_CUBE"][0].header.get(
                            "HIERARCH ESO INS OPTI1 NAME", "N/A"
                        )
                    ),
                    "DET.READ.CURNAME: "
                    + str(
                        hdul_dict["TWILIGHT_CUBE"][0].header.get(
                            "HIERARCH ESO DET READ CURNAME", "N/A"
                        )
                    ),
                    "DATANCOM: "
                    + str(
                        hdul_dict["TWILIGHT_CUBE"][0].header.get(
                            "HIERARCH ESO PRO DATANCOM", "N/A"
                        )
                    ),
                )

                textplot = TextPlot(columns=1, v_space=0.3)
                textplot.add_data(col1)
                panel.assign_plot(textplot, 0, 0, xext=2)
                textplot = TextPlot(columns=1, v_space=0.3)
                textplot.add_data(col2)
                panel.assign_plot(textplot, 2, 0, xext=2)
                # textplot.add_data(col2)

                addme = {
                    "report_name": "{}_{}".format(
                        self.name,
                        hdul_dict["TWILIGHT_CUBE"][0].header.get(
                            "HIERARCH ESO INS MODE", "N/A"
                        ),
                    ),
                    "report_description": f"MUSE sky flat",
                    "report_tags": [],
                }

                panels[panel] = addme
        return panels


rep = MuseSkyFlatReport()
