import os
from adari_core.plots.text import TextPlot
from adari_core.data_libs.master_astrometry import MasterAstrometryReport
from . import MuseReportMixin


class MuseThroughputReport(MuseReportMixin, MasterAstrometryReport):
    name = "muse_throughput"
    data_extensions = None
    image_category = "MASTER_AMPL"
    fov_per_panel = 1
    panel_kwargs = dict(x=6, y=4, height_ratios=[1, 5])

    def __init__(self):
        super().__init__(self.name)

    def parse_sof(self):
        """Returns a list of files selected from a set of frames (sof).

        If more than one file fullfills the criteria, the first file
        in the array will be selected.
        """
        files_needed = {self.image_category: None}
        for filename, catg in self.inputs:
            if (
                catg == self.image_category
                and files_needed[self.image_category] is None
            ):
                files_needed[self.image_category] = filename

        if files_needed[self.image_category] is None:
            raise IOError("[ERROR] {} file not found".format(self.image_category))

        return [files_needed]

    def generate_panels(self, **kwargs):
        self.data_extensions = ["CHAN{:02d}.DATA".format(i) for i in range(1, 25)]

        panels = super().generate_panels(
            zoom_in=False,
            zoom_in_extent=100,
            img_ext=(1, 1),
        )
        for i, (panel, panel_descr) in enumerate(panels.items()):
            hdul = self.hdus[i][self.image_category]
            setup = str(hdul["PRIMARY"].header.get("HIERARCH ESO INS MODE", "N/A"))
            panel_descr["report_name"] = "{}_{}".format(
                self.name,
                setup.lower(),
            )
            panel_descr["report_description"] = (
                f"{self.name} Panel - " f"{os.path.basename(hdul.filename())}, "
            )

            text_col = (
                "INS.MODE: {}".format(
                    str(hdul["PRIMARY"].header.get("HIERARCH ESO INS MODE", "N/A"))
                ),
                "INS.OPTI1.NAME: {}".format(
                    str(
                        hdul["PRIMARY"].header.get("HIERARCH ESO INS OPTI1 NAME", "N/A")
                    )
                ),
                "DET.READ.CURNAME: {}".format(
                    str(
                        hdul["PRIMARY"].header.get(
                            "HIERARCH ESO DET READ CURNAME", "N/A"
                        )
                    )
                ),
                "DATANCOM: {}".format(
                    str(hdul["PRIMARY"].header.get("HIERARCH ESO PRO DATANCOM", "N/A"))
                ),
            )
            text = TextPlot(columns=1, v_space=0.3)
            text.add_data(text_col)
            panel.assign_plot(text, 2, 0, xext=1)

        return panels


rep = MuseThroughputReport()
