from edps import QC1_CALIB, CALCHECKER
from edps import task, subworkflow, alternative_associated_inputs, ReportInput

from .muse_datasources import *
from .muse_task_functions import *


# This subworkflow reduces and eventually combine science exposures
@subworkflow("astrometry", "")
def process_astrometry(response, bias, dark, lamp_flat, wavelength, geometry_calibrations, sky_flat):
    # --- Pre-process astrometric raw calibrations
    preprocess_astrometry = (task("preprocess_astrometry")
                             .with_recipe("muse_scibasic")
                             .with_report("muse_rawdisp", ReportInput.RECIPE_INPUTS)
                             .with_main_input(raw_astrometry)
                             .with_associated_input(badpix_table, min_ret=0)
                             .with_associated_input(nonlinearity_gain, min_ret=0, condition=use_linearity_gain)
                             .with_associated_input(bias, [MASTER_BIAS])
                             .with_associated_input(dark, [MASTER_DARK], min_ret=0, condition=use_darks)
                             .with_associated_input(lamp_flat, [TRACE_TABLE, MASTER_FLAT])
                             .with_associated_input(wavelength, [WAVECAL_TABLE])
                             .with_alternative_associated_inputs(geometry_calibrations)
                             .with_associated_input(sky_flat, [TWILIGHT_CUBE], min_ret=1, condition=use_skyflats)
                             .with_associated_input(raw_flat_illum, min_ret=0)
                             .with_meta_targets([QC1_CALIB])
                             .build())

    # --- Generation of astrometry correction tables
    astrometry = (task("astrometry")
                  .with_recipe("muse_astrometry")
                  .with_report("muse_astrometry", ReportInput.RECIPE_INPUTS_OUTPUTS)
                  .with_main_input(preprocess_astrometry)
                  .with_associated_input(extinct_table, min_ret=0)
                  .with_associated_input(astrometry_reference)
                  .with_associated_input(response, [STD_RESPONSE, STD_TELLURIC], min_ret=0)
                  .with_meta_targets([QC1_CALIB, CALCHECKER])
                  .build())

    # -- Selection of astrometric calibration from user's choice. If the workflow parameter recompute_astrometry.
    #   recompute_astrometry: "yes", the reduced astrometric fields associated to the dataset are used.
    #   recompute_astrometry: "no", the static calibration included in the pipeline release is used.
    astrometry_calibrations = (alternative_associated_inputs()
                               .with_associated_input(astrometry, [ASTROMETRY_WCS], condition=recompute_astrometry)
                               .with_associated_input(astrometry_table))

    return astrometry, astrometry_calibrations
