from edps import classification_rule

from . import muse_keywords as kwd
from . import muse_rules as rules

#
# Dictionaries containing the values of header keywords that define calibrations and science
muse = {kwd.instrume: "MUSE"}
calib_ifu = {**muse, kwd.dpr_catg: "CALIB", kwd.dpr_tech: "IFU"}
calib_image = {**muse, kwd.dpr_catg: "CALIB", kwd.dpr_tech: "IMAGE"}
calib_static = {**muse, kwd.pro_type: "STATIC"}
science_ifu = {**muse, kwd.dpr_catg: "SCIENCE", kwd.dpr_tech: "IFU"}
technical_ifu = {**muse, kwd.dpr_catg: "TECHNICAL", kwd.dpr_tech: "IFU"}

# Raw data frames
bias_class = classification_rule("BIAS", {**calib_ifu, kwd.dpr_type: "BIAS"})
dark_class = classification_rule("DARK", {**calib_ifu, kwd.dpr_type: "DARK"})

throughput_class = classification_rule("AMPL", {**technical_ifu, kwd.dpr_type: "FLAT,LAMP,THRUPUT"})
lingain_bias_class = classification_rule("LINGAIN_LAMP_OFF", {**calib_ifu, kwd.dpr_type: "BIAS,DETCHECK"})
lingain_flat_class = classification_rule("LINGAIN_LAMP_ON", {**calib_ifu, kwd.dpr_type: "LINEARITY,FLAT,DETCHAR"})

flat_lamp_class = classification_rule("FLAT", rules.is_flat_lamp)
flat_sky_class = classification_rule("SKYFLAT", {**calib_ifu, kwd.dpr_type: "FLAT,SKY"})
flat_illum_class = classification_rule("ILLUM", rules.is_flat_illum)
mask_class = classification_rule("MASK", {**calib_ifu, kwd.dpr_type: "WAVE,MASK"})
lsf_class = classification_rule("ARC_LSF", {**calib_ifu, kwd.dpr_type: "WAVE,LSF"})
arc_class = classification_rule("ARC", {**calib_ifu, kwd.dpr_type: "WAVE"})
sky_class = classification_rule("SKY", rules.is_sky)
std_class = classification_rule("STD", {**calib_ifu, kwd.dpr_type: "STD"})
astrometry_class = classification_rule("ASTROMETRY", {**calib_ifu, kwd.dpr_type: "ASTROMETRY"})
object_class = classification_rule("OBJECT", {**science_ifu, kwd.dpr_type: "OBJECT"})

# Static data frames
sky_lines_class = classification_rule("SKY_LINES", {**calib_static, kwd.pro_catg: "SKY_LINES"})
badpix_table_class = classification_rule("BADPIX_TABLE", {**calib_static, kwd.pro_catg: "BADPIX_TABLE"})
nonlinearity_gain_class = classification_rule("NONLINEARITY_GAIN", {**calib_static, kwd.pro_catg: "NONLINEARITY_GAIN"})
vignetting_mask_class = classification_rule("VIGNETTING_MASK", {**calib_static, kwd.pro_catg: "VIGNETTING_MASK"})
line_catalog_class = classification_rule("LINE_CATALOG", {**calib_static, kwd.pro_catg: "LINE_CATALOG"})
extinct_table_class = classification_rule("EXTINCT_TABLE", {**calib_static, kwd.pro_catg: "EXTINCT_TABLE"})
filter_list_class = classification_rule("FILTER_LIST", {**calib_static, kwd.pro_catg: "FILTER_LIST"})
std_flux_table_class = classification_rule("STD_FLUX_TABLE", {**calib_static, kwd.pro_catg: "STD_FLUX_TABLE"})
telluric_regions_class = classification_rule("TELLURIC_REGIONS", {**calib_static, kwd.pro_catg: "TELLURIC_REGIONS"})
astrometry_reference_class = classification_rule("ASTROMETRY_REFERENCE",
                                                 {**calib_static, kwd.pro_catg: "ASTROMETRY_REFERENCE"})
raman_lines_class = classification_rule("RAMAN_LINES", {**calib_static, kwd.pro_catg: "RAMAN_LINES"})
static_astrometry_wcs_class = classification_rule("ASTROMETRY_WCS", {**calib_static, kwd.pro_catg: "ASTROMETRY_WCS"})
static_geometry_table = classification_rule("GEOMETRY_TABLE", {**calib_static, kwd.pro_catg: "GEOMETRY_TABLE"})

# Master Calibration data frame
MASTER_BIAS = classification_rule("MASTER_BIAS", {**muse, kwd.pro_catg: "MASTER_BIAS"})
MASTER_DARK = classification_rule("MASTER_DARK", {**muse, kwd.pro_catg: "MASTER_DARK"})
MASTER_FLAT = classification_rule("MASTER_FLAT", {**muse, kwd.pro_catg: "MASTER_FLAT"})
TRACE_TABLE = classification_rule("TRACE_TABLE", {**muse, kwd.pro_catg: "TRACE_TABLE"})
WAVECAL_TABLE = classification_rule("WAVECAL_TABLE", {**muse, kwd.pro_catg: "WAVECAL_TABLE"})
TWILIGHT_CUBE = classification_rule("TWILIGHT_CUBE", {**muse, kwd.pro_catg: "TWILIGHT_CUBE"})
STD_RESPONSE = classification_rule("STD_RESPONSE", {**muse, kwd.pro_catg: "STD_RESPONSE"})
STD_TELLURIC = classification_rule("STD_TELLURIC", {**muse, kwd.pro_catg: "STD_TELLURIC"})
SKY_CONTINUUM = classification_rule("SKY_CONTINUUM", {**muse, kwd.pro_catg: "SKY_CONTINUUM"})
SKY_MASK = classification_rule("SKY_MASK", {**muse, kwd.pro_catg: "SKY_MASK"})
# Those needs to be distinguished by corresponding static that have pro.type="STATIC"
MASTER_SKYLINES = classification_rule("SKY_LINES", rules.is_master_skyline)
GEOMETRY_TABLE = classification_rule("GEOMETRY_TABLE", rules.is_master_geometry_table)
ASTROMETRY_WCS = classification_rule("ASTROMETRY_WCS", rules.is_master_astrometry_wcs)
LSF_PROFILE = classification_rule("LSF_PROFILE", rules.is_master_lsf_profile)
ARC_RED_LAMP = classification_rule("ARC_RED_LAMP", {**muse, kwd.pro_catg: "ARC_RED_LAMP"})
DATACUBE_SKYFLAT = classification_rule("DATACUBE_SKYFLAT", {**muse, kwd.pro_catg: "DATACUBE_SKYFLAT"})
# Other products or user provided data frames
offset_list_class = classification_rule("OFFSET_LIST", {**muse, kwd.pro_catg: "OFFSET_LIST"})
source_list_class = classification_rule("SOURCE_LIST", {**muse, kwd.pro_catg: "SOURCE_LIST"})
output_wcs_class = classification_rule("OUTPUT_WCS", {**muse, kwd.pro_catg: "OUTPUT_WCS"})
autocal_factors_class = classification_rule("AUTOCAL_FACTORS", {**muse, kwd.pro_catg: "AUTOCAL_FACTORS"})
image_fov_class = classification_rule("IMAGE_FOV", {**muse, kwd.pro_catg: "IMAGE_FOV"})
pixtable_reduced_class = classification_rule("PIXTABLE_REDUCED", {**muse, kwd.pro_catg: "PIXTABLE_REDUCED"})
pixtable_object_class = classification_rule("PIXTABLE_OBJECT", {**muse, kwd.pro_catg: "PIXTABLE_OBJECT"})
pixtable_sky_class = classification_rule("PIXTABLE_SKY", {**muse, kwd.pro_catg: "PIXTABLE_SKY"})
lsf_static_class = classification_rule("LSF_PROFILE", {**calib_static, kwd.pro_catg: "LSF_PROFILE"})
