from edps import QC1_CALIB, CALCHECKER, task, subworkflow, ReportInput, FilterMode

from .muse_datasources import *
from .muse_task_functions import *


# This subworkflow reduces standard star observations and produces response curve and telluric correction
@subworkflow("response", "")
def process_standard(bias, dark, lamp_flat, wavelength, geometry_calibrations, sky_flat):
    # --- Pre-process standard star raw calibrations
    preprocess_standard = (task("preprocess_standard")
                           .with_recipe("muse_scibasic")
                           .with_report("muse_rawdisp", ReportInput.RECIPE_INPUTS)
                           .with_main_input(raw_std)
                           .with_associated_input(badpix_table, min_ret=0)
                           .with_associated_input(nonlinearity_gain, min_ret=0, condition=use_linearity_gain)
                           .with_associated_input(bias, [MASTER_BIAS])
                           .with_associated_input(dark, [MASTER_DARK], min_ret=0, condition=use_darks)
                           .with_associated_input(lamp_flat, [TRACE_TABLE, MASTER_FLAT])
                           .with_associated_input(wavelength, [WAVECAL_TABLE])
                           .with_alternative_associated_inputs(geometry_calibrations)
                           .with_associated_input(sky_flat, [TWILIGHT_CUBE], min_ret=1, condition=use_skyflats)
                           .with_associated_input(raw_flat_illum, min_ret=0)
                           .with_input_filter(ARC_RED_LAMP, mode=FilterMode.REJECT)
                           .with_meta_targets([QC1_CALIB, CALCHECKER])
                           .build())

    # --- Generation of response curve and telluric correction
    response = (task("response")
                .with_recipe("muse_standard")
                .with_report("muse_std_star", ReportInput.RECIPE_INPUTS_OUTPUTS, driver='png')
                .with_main_input(preprocess_standard)
                .with_associated_input(extinct_table)
                .with_associated_input(std_flux_table)
                .with_associated_input(telluric_regions, min_ret=0)
                .with_associated_input(filter_list, min_ret=0)
                .with_job_processing(wavelength_range)
                .with_meta_targets([CALCHECKER, QC1_CALIB])
                .build())

    return response
