from edps import like, regexp

from . import muse_keywords as kwd


def is_muse(f):
    return f[kwd.instrume] == "MUSE"


def is_calib(f):
    return is_muse(f) and f[kwd.dpr_catg] == "CALIB"


def is_science(f):
    return is_muse(f) and f[kwd.dpr_catg] == "SCIENCE"


def is_ifu(f):
    return f[kwd.dpr_tech] == "IFU"


def ins_opti1_name(f):
    return like(f[kwd.ins_opti1_name], "Blue%")


def is_flat_lamp(f):
    return is_calib(f) and is_ifu(f) and \
        regexp(f[kwd.tpl_id], "MUSE_[wn]fm_cal_specflat") and \
        f[kwd.dpr_type] == "FLAT,LAMP"


def is_flat_illum(f):
    return is_calib(f) and is_ifu(f) and f[kwd.dpr_type] in ["FLAT,LAMP,ILLUM", "FLAT,LAMP,ATT"]
    #  (regexp(f[kwd.tpl_id], "MUSE_[wn]fm_cal_illum") or regexp(f[kwd.tpl_id], "MUSE_[wn]fm_cal_specflat")) and \
    #  f[kwd.dpr_type] in ["FLAT,LAMP,ILLUM", "FLAT,LAMP,ATT"]


def is_sky(f):
    return (is_science(f) or is_calib(f)) and is_ifu(f) and f[kwd.dpr_type] == "SKY"


def is_master_skyline(f):
    return f[kwd.pro_catg] == "SKY_LINES" and f[kwd.pro_type] != "STATIC" and is_muse(f)


def is_master_geometry_table(f):
    return f[kwd.pro_catg] == "GEOMETRY_TABLE" and f[kwd.pro_type] != "STATIC" and is_muse(f)


def is_master_astrometry_wcs(f):
    return f[kwd.pro_catg] == "ASTROMETRY_WCS" and f[kwd.pro_type] != "STATIC" and is_muse(f)


def is_master_lsf_profile(f):
    return f[kwd.pro_catg] == "LSF_PROFILE" and f[kwd.pro_type] != "STATIC" and is_muse(f)


# ASSOCIATION RULES
#  -  first, e.g.  ref=trigger (e.g. science)
#  -  second, e.g.  f=file to associate (e.g. calibration)

def is_associated_raman_lines(ref, f):
    return f[kwd.instrume] == ref[kwd.instrume] and ref[kwd.ins_mode] in ['WFM-AO-N', 'WFM-AO-E', 'NFM-AO-N',
                                                                          'NFM-AO-E']


def is_associated(ref, f):
    return True
